Documentation
¶
Index ¶
Constants ¶
const ( Bucket = "entries" Type = "entry" )
Bucket is the name of the bucket storing all the entries
Variables ¶
This section is empty.
Functions ¶
Types ¶
type Data ¶
type Data struct {
Type string `json:"type,omitempty"`
Attributes *Entry `json:"attributes,omitempty"`
Links *Links `json:"links,omitempty"`
}
Data contains the Type of the request and the Attributes
type Entry ¶
type Entry struct {
ID int `json:"id"`
Title string `json:"title"`
Markdown string `json:"markdown"`
}
Entry is the main struct
type MultiWrapper ¶
type MultiWrapper struct {
Data *[]Data `json:"data,omitempty"`
Errors *hateoas.Errors `json:"errors,omitempty"`
}
MultiWrapper is a wrapper that can accept multiple Data
Click to show internal directories.
Click to hide internal directories.